@@ -25,10 +25,6 @@ coordinator.includeFile('disorder/tests/RecreateSet.js');
 coordinator.includeFile('disorder/tests/MergeSet.js');
 coordinator.includeFile('disorder/tests/BulkAddingTest.js');
 coordinator.includeFile('disorder/tests/WaitForTest.js');
-coordinator.includeFile('disorder/tests/MultinodeFailover.js');
-coordinator.includeFile('disorder/tests/Resubscribe.js');
-coordinator.includeFile('disorder/tests/SiteFailover.js');
-
 var tests = 
     [new EmptySet(coordinator,results)
      ,new OmitCopy(coordinator,results)
@@ -54,18 +50,13 @@ var tests =
      ,new MergeSet(coordinator,results)
      ,new BulkAddingTest(coordinator,results)
 	 ,new WaitForTest(coordinator,results)
-	 ,new MultinodeFailover(coordinator,results)
-	 ,new Resubscribe(coordinator,results)
-	 ,new SiteFailover(coordinator,results)
 	 //Below tests are known to fail.
 	 ,new UnsubscribeBeforeEnable(coordinator,results)
      ,new DropSet(coordinator,results) //fails bug 133
      ,new CleanupTest(coordinator,results) //cleanup_interval does not (yet) do what the test wants
     ];
 
-//tests=[new Failover(coordinator,results),
-//	   new MultinodeFailover(coordinator,results)
-//	   ,new SiteFailover(coordinator,results)];
+//tests=[new WaitForTest(coordinator,results)];
 
 var basicTest = new BasicTest(coordinator,results);
 
