@@ -6,7 +6,7 @@
 --	Copyright (c) 2003-2009, PostgreSQL Global Development Group
 --	Author: Jan Wieck, Afilias USA INC.
 --
--- $Id: slony1_base.sql,v 1.40.2.3 2009-08-17 17:09:58 devrim Exp $
+-- 
 -- ----------------------------------------------------------------------
 
 
@@ -235,7 +235,7 @@ comment on column @NAMESPACE@.sl_subscribe.sub_active is 'Has this subscription
 create table @NAMESPACE@.sl_event (
 	ev_origin			int4,
 	ev_seqno			int8,
-	ev_timestamp		timestamp,
+	ev_timestamp		timestamptz,
 	ev_snapshot			"pg_catalog".txid_snapshot,
 	ev_type				text,
 	ev_data1			text,
@@ -303,7 +303,7 @@ create table @NAMESPACE@.sl_confirm (
 	con_origin			int4,
 	con_received		int4,
 	con_seqno			int8,
-	con_timestamp		timestamp DEFAULT timeofday()::timestamp
+	con_timestamp		timestamptz DEFAULT timeofday()::timestamptz
 ) WITHOUT OIDS;
 comment on table @NAMESPACE@.sl_confirm is 'Holds confirmation of replication events.  After a period of time, Slony removes old confirmed events from both this table and the sl_event table.';
 
@@ -341,22 +341,21 @@ create index sl_seqlog_idx on @NAMESPACE@.sl_seqlog
 --
 --	Support function used in sl_seqlastvalue view
 -- ----------------------------------------------------------------------
-create function @NAMESPACE@.sequenceLastValue(text) returns int8
-as '
+create function @NAMESPACE@.sequenceLastValue(p_seqname text) returns int8
+as $$
 declare
-	p_seqname	alias for $1;
 	v_seq_row	record;
 begin
-	for v_seq_row in execute ''select last_value from '' || @NAMESPACE@.slon_quote_input(p_seqname)
+	for v_seq_row in execute 'select last_value from ' || @NAMESPACE@.slon_quote_input(p_seqname)
 	loop
 		return v_seq_row.last_value;
 	end loop;
 
 	-- not reached
 end;
-' language plpgsql;
+$$ language plpgsql;
 
-comment on function @NAMESPACE@.sequenceLastValue(text) is
+comment on function @NAMESPACE@.sequenceLastValue(p_seqname text) is
 'sequenceLastValue(p_seqname)
 
 Utility function used in sl_seqlastvalue view to compactly get the
@@ -419,7 +418,7 @@ create table @NAMESPACE@.sl_registry (
 	reg_key				text primary key,
 	reg_int4			int4,
 	reg_text			text,
-	reg_timestamp		timestamp
+	reg_timestamp		timestamptz
 ) WITHOUT OIDS;
 comment on table @NAMESPACE@.sl_registry is 'Stores miscellaneous runtime data';
 comment on column @NAMESPACE@.sl_registry.reg_key is 'Unique key of the runtime option';
@@ -534,6 +533,20 @@ comment on table @NAMESPACE@.sl_config_lock is 'This table exists solely to prev
 ';
 comment on column @NAMESPACE@.sl_config_lock.dummy is 'No data ever goes in this table so the contents never matter.  Indeed, this column does not really need to exist.';
 
+-- ----------------------------------------------------------------------
+-- TABLE sl_event_lock
+--
+--	This table exists solely to prevent multiple connections from
+--	concurrently creating new events.  We separate this from
+--	sl_event because we really don't need a lock that prevents
+--	*reads* on sl_event.
+-- ----------------------------------------------------------------------
+create table @NAMESPACE@.sl_event_lock (
+	dummy				integer
+);
+comment on table @NAMESPACE@.sl_event_lock is 'This table exists solely to prevent multiple connections from concurrently creating new events and perhaps getting them out of order.';
+comment on column @NAMESPACE@.sl_event_lock.dummy is 'No data ever goes in this table so the contents never matter.  Indeed, this column does not really need to exist.';
+
 -- ----------------------------------------------------------------------
 -- TABLE sl_archive_counter
 --
@@ -541,7 +554,7 @@ comment on column @NAMESPACE@.sl_config_lock.dummy is 'No data ever goes in this
 -- ----------------------------------------------------------------------
 create table @NAMESPACE@.sl_archive_counter (
 	ac_num			bigint,
-	ac_timestamp	timestamp
+	ac_timestamp	timestamptz
 ) without oids;
 comment on table @NAMESPACE@.sl_archive_counter is 'Table used to generate the log shipping archive number.
 ';
@@ -549,7 +562,35 @@ comment on column @NAMESPACE@.sl_archive_counter.ac_num is 'Counter of SYNC ID u
 comment on column @NAMESPACE@.sl_archive_counter.ac_timestamp is 'Time at which the archive log was generated on the subscriber';
 
 insert into @NAMESPACE@.sl_archive_counter (ac_num, ac_timestamp)
-	values (0, 'epoch'::timestamp);
+	values (0, 'epoch'::timestamptz);
+
+-- ----------------------------------------------------------------------
+-- TABLE sl_components
+--
+--  This table captures the state of each Slony component to help
+--  with monitoring
+-- ----------------------------------------------------------------------
+create table @NAMESPACE@.sl_components (
+	co_actor	 text not null primary key,
+	co_pid		 integer not null,
+	co_node		 integer not null,
+	co_connection_pid integer not null,
+	co_activity	  text,
+	co_starttime	  timestamptz not null,
+	co_event	  bigint,
+	co_eventtype 	  text
+) without oids;
+
+comment on table @NAMESPACE@.sl_components is 'Table used to monitor what various slon/slonik components are doing';
+comment on column @NAMESPACE@.sl_components.co_actor is 'which component am I?';
+comment on column @NAMESPACE@.sl_components.co_pid is 'my process/thread PID on node where slon runs';
+comment on column @NAMESPACE@.sl_components.co_node is 'which node am I servicing?';
+comment on column @NAMESPACE@.sl_components.co_connection_pid is 'PID of database connection being used on database server';
+comment on column @NAMESPACE@.sl_components.co_activity is 'activity that I am up to';
+comment on column @NAMESPACE@.sl_components.co_starttime is 'when did my activity begin?  (timestamp reported as per slon process on server running slon)';
+comment on column @NAMESPACE@.sl_components.co_eventtype is 'what kind of event am I processing?  (commonly n/a for event loop main threads)';
+comment on column @NAMESPACE@.sl_components.co_event is 'which event have I started processing?';
+
 
 -- ----------------------------------------------------------------------
 -- Last but not least grant USAGE to the replication schema objects.
