@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	
+ *
  *-------------------------------------------------------------------------
  */
 
@@ -33,7 +33,6 @@
  */
 int			vac_frequency = SLON_VACUUM_FREQUENCY;
 char	   *cleanup_interval;
-bool		cleanup_deletelogs;
 
 static int	vac_bias = 0;
 static unsigned long earliest_xid = 0;
@@ -93,33 +92,40 @@ cleanupThread_main( /* @unused@ */ void *dummy)
 
 	dbconn = conn->dbconn;
 
+	monitor_state("local_cleanup", 0, conn->conn_pid, "thread main loop", 0, "n/a");
+
 	/*
 	 * Build the query string for calling the cleanupEvent() stored procedure
 	 */
 	dstring_init(&query_baseclean);
-	slon_mkquery(&query_baseclean, "select %s.cleanupEvent('%s'::interval, '%s'::boolean); ",
+	slon_mkquery(&query_baseclean,
+				 "begin;"
+				 "lock table %s.sl_config_lock;"
+				 "select %s.cleanupEvent('%s'::interval);"
+				 "commit;",
 				 rtcfg_namespace,
-				 cleanup_interval,
-				 cleanup_deletelogs ? "true" : "false"
+				 rtcfg_namespace,
+				 cleanup_interval
 		);
 	dstring_init(&query2);
 
 	/*
 	 * Loop until shutdown time arrived
 	 *
-	 * Note the introduction of vac_bias and an up-to-100s random
-	 * "fuzz"; this reduces the likelihood that having multiple slons
-	 * hitting the same cluster will run into conflicts due to trying
-	 * to vacuum common tables * such as pg_listener concurrently
+	 * Note the introduction of vac_bias and an up-to-100s random "fuzz"; this
+	 * reduces the likelihood that having multiple slons hitting the same
+	 * cluster will run into conflicts due to trying to vacuum common tables *
+	 * such as pg_listener concurrently
 	 */
 	while (sched_wait_time(conn, SCHED_WAIT_SOCK_READ, SLON_CLEANUP_SLEEP * 1000 + vac_bias + (rand() % (SLON_CLEANUP_SLEEP * 166))) == SCHED_STATUS_OK)
 	{
 		/*
 		 * Call the stored procedure cleanupEvent()
 		 */
+		monitor_state("local_cleanup", 0, conn->conn_pid, "cleanupEvent", 0, "n/a");
 		gettimeofday(&tv_start, NULL);
 		res = PQexec(dbconn, dstring_data(&query_baseclean));
-		if (PQresultStatus(res) != PGRES_TUPLES_OK)
+		if (PQresultStatus(res) != PGRES_COMMAND_OK)
 		{
 			slon_log(SLON_FATAL,
 					 "cleanupThread: \"%s\" - %s",
@@ -189,6 +195,7 @@ cleanupThread_main( /* @unused@ */ void *dummy)
 			ntuples = PQntuples(res);
 			slon_log(SLON_DEBUG1, "cleanupThread: number of tables to clean: %d\n", ntuples);
 
+			monitor_state("local_cleanup", 0, conn->conn_pid, "vacuumTables", 0, "n/a");
 			for (t = 0; t < ntuples; t++)
 			{
 				char	   *tab_nspname = PQgetvalue(res, t, 0);
@@ -206,17 +213,20 @@ cleanupThread_main( /* @unused@ */ void *dummy)
 				{
 					slon_log(SLON_ERROR,
 							 "cleanupThread: \"%s\" - %s\n",
-							 dstring_data(&query_pertbl), PQresultErrorMessage(res2));
+					dstring_data(&query_pertbl), PQresultErrorMessage(res2));
 
 					/*
 					 * slon_retry(); break;
 					 */
-				} else {
-					if (vrc == PGRES_NONFATAL_ERROR) {
+				}
+				else
+				{
+					if (vrc == PGRES_NONFATAL_ERROR)
+					{
 						slon_log(SLON_WARN,
 								 "cleanupThread: \"%s\" - %s\n",
 								 dstring_data(&query_pertbl), PQresultErrorMessage(res2));
-						
+
 					}
 				}
 				PQclear(res2);
@@ -232,6 +242,7 @@ cleanupThread_main( /* @unused@ */ void *dummy)
 			 */
 			dstring_free(&query_pertbl);
 			PQclear(res);
+			monitor_state("local_cleanup", 0, conn->conn_pid, "thread main loop", 0, "n/a");
 		}
 	}
 
@@ -268,7 +279,7 @@ cleanupThread_main( /* @unused@ */ void *dummy)
 static unsigned long
 get_earliest_xid(PGconn *dbconn)
 {
-	int64	xid;
+	int64		xid;
 	PGresult   *res;
 	SlonDString query;
 
