@@ -94,7 +94,7 @@ static struct config_int ConfigureNamesInt[] =
 			(const char *) "desired_sync_time",
 			gettext_noop("maximum time planned for grouped SYNCs"),
 			gettext_noop("If replication is behind, slon will try to increase numbers of "
-			  "syncs done targetting that they should take this quantity of "
+			  "syncs done targeting that they should take this quantity of "
 						 "time to process"),
 			SLON_C_INT
 		},
