@@ -27,6 +27,10 @@ extern int	desired_sync_time;
 
 extern int	quit_sync_provider;
 extern int	quit_sync_finalsync;
+extern bool  keep_alive;
+extern int  keep_alive_idle;
+extern int  keep_alive_interval;
+extern int  keep_alive_count;
 
 /*
  * ----------
@@ -36,7 +40,6 @@ extern int	quit_sync_finalsync;
 
 extern int	vac_frequency;
 extern char *cleanup_interval;
-extern bool cleanup_deletelogs;
 
 char	   *Syslog_ident;
 char	   *Syslog_facility;
