@@ -20,13 +20,20 @@
 #include <errno.h>
 #include <signal.h>
 #include <sys/types.h>
+#include <sys/socket.h>
 #ifndef WIN32
 #include <sys/time.h>
 #include <unistd.h>
+#include <netinet/tcp.h>
+#include <netinet/in.h>
 #endif
 
 #include "slon.h"
 
+bool keep_alive;
+int keep_alive_idle;
+int keep_alive_count;
+int keep_alive_interval;
 
 static int	slon_appendquery_int(SlonDString *dsp, char *fmt, va_list ap);
 static int	db_get_version(PGconn *conn);
@@ -56,6 +63,7 @@ slon_connectdb(char *conninfo, char *symname)
 	SlonConn   *conn;
 	PGresult   *res;
 	SlonDString query;
+	int         connpid = -1;
 
 	/*
 	 * Create the native database connection
@@ -83,6 +91,56 @@ slon_connectdb(char *conninfo, char *symname)
 		return NULL;
 	}
 
+	setsockopt(PQsocket(dbconn),SOL_SOCKET,SO_KEEPALIVE,&keep_alive,
+			   sizeof(int));
+#ifndef WIN32
+	if(keep_alive)
+	{
+		
+		if(keep_alive_idle > 0)
+#ifdef TCP_KEEPIDLE
+			setsockopt(PQsocket(dbconn),IPPROTO_TCP,TCP_KEEPIDLE,
+					   &keep_alive_idle,sizeof(keep_alive_idle));
+#else
+			slon_log(SLON_WARN,"keep_alive_idle is not supported on this platform");
+#endif
+		if(keep_alive_interval > 0)
+#ifdef TCP_KEEPINTVL
+			setsockopt(PQsocket(dbconn),IPPROTO_TCP,TCP_KEEPINTVL,
+					   &keep_alive_interval,sizeof(keep_alive_interval));
+#else
+			slon_log(SLON_WARN,"keep_alive_interval is not supported on this platform");
+#endif
+		if(keep_alive_count > 0)
+#ifdef TCP_KEEPCNT
+			setsockopt(PQsocket(dbconn),IPPROTO_TCP,TCP_KEEPCNT,
+					   &keep_alive_count,sizeof(keep_alive_count));
+#else
+			slon_log(SLON_WARN,"keep_alive_count is not supported on this platform");
+#endif
+		
+	}
+#else
+	/**
+	 * Win32 does not support the setsockopt calls for setting keep alive
+	 * parameters.  On Win32 this can be adjusted via the registry.
+	 * libpq 9.0 and above provide functions for doing this.
+	 * If we ever require libpq9.0 or above we could start to use them.
+	 * Alternativly someone could re-implement that functionality inside
+	 * of slony.
+	 */
+	if(keep_alive)
+	{
+		if(keep_alive_idle > 0 )
+			slon_log(SLON_WARN,"keep_alive_idle is not supported by Slony on Win32");
+		if(keep_alive_interval > 0) 
+			slon_log(SLON_WARN,"keep_alive_interval is not supported by Slony on Win32");
+		if(keep_alive_count > 0) 
+			slon_log(SLON_WARN,"keep_alive_count is not supported by Slony Win32");
+
+	}
+#endif
+
 	dstring_init(&query);
 
 	if (sql_on_connection != NULL)
@@ -109,6 +167,17 @@ slon_connectdb(char *conninfo, char *symname)
 	}
 	PQclear(res);
 
+	/* Find PID for connection */
+	slon_mkquery(&query, "select pg_catalog.pg_backend_pid();");
+	res = PQexec(dbconn, dstring_data(&query));
+	if (!(PQresultStatus(res) == PGRES_TUPLES_OK))
+	{
+			slon_log(SLON_ERROR, "Unable to check connection PID\n");
+	} else {
+			connpid = strtol(PQgetvalue(res, 0, 0), NULL, 10);
+	}
+	PQclear(res);
+
 	/*
 	 * Embed it into a SlonConn structure used to exchange it with the
 	 * scheduler. On return this new connection object is locked.
@@ -116,6 +185,7 @@ slon_connectdb(char *conninfo, char *symname)
 	conn = slon_make_dummyconn(symname);
 	conn->dbconn = dbconn;
 	conn->pg_version = db_get_version(dbconn);
+	conn->conn_pid = connpid;
 	if (conn->pg_version < 80300)
 	{
 		slon_log(SLON_ERROR,
@@ -147,6 +217,16 @@ slon_connectdb(char *conninfo, char *symname)
 		PQclear(res);
 	}
 
+	slon_mkquery(&query, "select %s.store_application_name('slon.%s');",
+				 rtcfg_namespace, symname);
+	res = PQexec(dbconn, dstring_data(&query));
+	if (PQresultStatus(res) != PGRES_TUPLES_OK)
+	{
+			slon_log(SLON_ERROR, "Unable to submit application_name store request\n");
+	}
+	PQclear(res);
+
+
 	if (slon_log_level >= SLON_DEBUG1)
 	{
 		slon_mkquery(&query, "select pg_backend_pid()");
@@ -403,7 +483,7 @@ db_checkSchemaVersion(PGconn *conn)
  *	   %d	Integer argument
  * ----------
  */
-int
+void
 slon_mkquery(SlonDString *dsp, char *fmt,...)
 {
 	va_list		ap;
@@ -415,8 +495,6 @@ slon_mkquery(SlonDString *dsp, char *fmt,...)
 	va_end(ap);
 
 	dstring_terminate(dsp);
-
-	return 0;
 }
 
 
@@ -426,7 +504,7 @@ slon_mkquery(SlonDString *dsp, char *fmt,...)
  * Append query string material to an existing dynamic string.
  * ----------
  */
-int
+void
 slon_appendquery(SlonDString *dsp, char *fmt,...)
 {
 	va_list		ap;
@@ -436,8 +514,6 @@ slon_appendquery(SlonDString *dsp, char *fmt,...)
 	va_end(ap);
 
 	dstring_terminate(dsp);
-
-	return 0;
 }
 
 
