@@ -26,14 +26,15 @@
 #include <time.h>
 #include <signal.h>
 #include <dirent.h>
+#include <string.h>
 #else
 #define sleep(x) Sleep(x*1000)
 #define vsnprintf _vsnprintf
 #endif
 
-#include "postgres.h"
 #include "libpq-fe.h"
 
+#include "../slonik/types.h"
 #include "slony_logshipper.h"
 #include "config.h"
 
@@ -622,7 +623,7 @@ process_check_at_counter(char *at_counter)
 {
 	char	buf1[64];
 	char	buf2[64];
-	int		i;
+	size_t		i;
 
 	if (destination_conninfo == NULL)
 		return 0;
@@ -796,6 +797,29 @@ process_delete(DeleteStmt *stmt)
 }
 
 
+int
+process_truncate(TruncateStmt *stmt)
+{
+	SlonDString		ds;
+	int				rc;
+	char		   *namespace;
+	char		   *tablename;
+
+	if (lookup_rename(stmt->namespace, stmt->tablename, 
+					&namespace, &tablename) == 0)
+		return 0;
+
+	dstring_init(&ds);
+	slon_mkquery(&ds, "truncate only %s.%s cascade;", 
+				  namespace, tablename);
+	dstring_terminate(&ds);
+
+	rc = process_exec_sql(dstring_data(&ds));
+	dstring_free(&ds);
+
+	return rc;
+}
+
 int
 process_copy(CopyStmt *stmt)
 {
