@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: slony_logshipper.h,v 1.4.2.1 2009-08-17 17:09:59 devrim Exp $
+ *	
  *-------------------------------------------------------------------------
  */
 
@@ -122,6 +122,11 @@ typedef struct DeleteStmt_s {
 	AttElemList		   *qualification;
 } DeleteStmt;
 
+typedef struct TruncateStmt_s {
+  char					*namespace;
+  char					*tablename;
+} TruncateStmt;
+
 typedef struct CopyStmt_s {
 	char			   *namespace;
 	char			   *tablename;
@@ -191,6 +196,7 @@ extern int		process_end_transaction(char *sql);
 extern int		process_insert(InsertStmt *stmt);
 extern int		process_update(UpdateStmt *stmt);
 extern int		process_delete(DeleteStmt *stmt);
+extern int		process_truncate(TruncateStmt *stmt);
 extern int		process_copy(CopyStmt *stmt);
 extern int		process_copydata(char *line);
 extern int		process_copyend(void);
