@@ -69,6 +69,7 @@ done
 cat <<_EOF_
 start transaction;
 
+
 -- ----------------------------------------------------------------------
 -- SCHEMA $clname
 -- ----------------------------------------------------------------------
@@ -165,9 +166,18 @@ begin
 end;
 ' language plpgsql;
 
+set session_replication_role='replica';
+
 _EOF_
 
 
+
+for tab in $tables
+do
+	eval tabname=\$tabname_$tab
+	echo "truncate $tabname cascade;";
+done
+
 # ----
 # The remainder of this script is written in a way that
 # all output is generated by psql inside of one serializable
@@ -185,7 +195,7 @@ echo "set transaction isolation level serializable;"
 # ----
 echo "select 'copy $clname.sl_sequence_offline from stdin;';"
 echo "select seq_id::text || '	' || seq_relname  || '	' || seq_nspname from $clname.sl_sequence;"
-printf "select '\\\\\\\\.';"
+printf "select E'\\\\\\\\.';"
 
 for seq in $sequences ; do
 	eval seqname=\$seqname_$seq
@@ -206,11 +216,12 @@ echo "select 'insert into $clname.sl_archive_tracking values (' ||
 system_type=`uname`
 for tab in $tables ; do
 	eval tabname=\$tabname_$tab
+
 	# Get fieldnames...
  	fields=`psql -At -c "select $clname.copyfields($tab);" $dbname`
  	echo "select 'copy $tabname $fields from stdin;';"
 	echo "copy $tabname $fields to stdout;"
- 	printf "select '\\\\\\\\.';"
+ 	printf "select E'\\\\\\\\.';"
 done
 
 # ----
